@@ -6,8 +6,7 @@ test_that("error when using unsupported window function median()", {
     x %>% group_by(playerid) %>% mutate(median(g)) %>% collect()
   }
   expect_error(
-    test_op(tbl(impala, in_schema("lahman", "batting"))),
-    regexp = "not supported"
+    test_op(tbl(impala, in_schema("lahman", "batting")))
   )
 })
 
@@ -17,8 +16,7 @@ test_that("error when using unsupported window function n_distinct()", {
     x %>% group_by(playerid) %>% mutate(n_distinct(g)) %>% collect()
   }
   expect_error(
-    test_op(tbl(impala, in_schema("lahman", "batting"))),
-    regexp = "not supported"
+    test_op(tbl(impala, in_schema("lahman", "batting")))
   )
 })
 
@@ -29,7 +27,7 @@ test_that("error when using unsupported window function ndv()", {
   }
   expect_error(
     test_op(tbl(impala, in_schema("lahman", "batting"))),
-    regexp = "not supported"
+    regexp = "not.supported"
   )
 })
 
@@ -40,7 +38,7 @@ test_that("error when using unsupported window function sd()", {
   }
   expect_error(
     test_op(tbl(impala, in_schema("lahman", "batting"))),
-    regexp = "not supported"
+    regexp = "not.supported"
   )
 })
 
@@ -51,6 +49,6 @@ test_that("error when using unsupported window function var()", {
   }
   expect_error(
     test_op(tbl(impala, in_schema("lahman", "batting"))),
-    regexp = "not supported"
+    regexp = "not.supported"
   )
 })
